@@ -7,8 +7,8 @@ def main():
 	configparser = ConfigParser()
 	starterpkg = StarterPkg(configparser)
 	#starterpkg.run()
-	print(configparser.filepath)
-	resource_filename(Requirement.parse('pythonstarterpackage'),'config')
+	#print(configparser.filepath)
+	print(resource_filename('pythonstarterpackage','config/config.json'))
 
 if __name__ == '__main__':
 	raise SystemExit(main())
\ No newline at end of file
